# The Social Network

The package "The Social Network" is a django base backend core element for any possible social network you can think of.

It contains the following models

Django.Authentication.User
